==> libreoffice-6.4.7.2.tar.xz: libreoffice-6.4.7.2/sc/source/ui/miscdlgs/groupdlg.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#undef SC_DLLIMPLEMENTATION

#include <groupdlg.hxx>

ScGroupDlg::ScGroupDlg(weld::Window* pParent, bool bUngroup, bool bRows)
    : GenericDialogController(pParent,
        bUngroup ?
            OUString("modules/scalc/ui/ungroupdialog.ui") :
            OUString("modules/scalc/ui/groupdialog.ui")
    ,
        bUngroup ?
            OString("UngroupDialog") :
            OString("GroupDialog"))
    , m_xBtnRows(m_xBuilder->weld_radio_button("rows"))
    , m_xBtnCols(m_xBuilder->weld_radio_button("cols"))
{
    if (bRows)
        m_xBtnRows->set_active(true);
    else
        m_xBtnCols->set_active(true);
    m_xBtnRows->grab_focus();
}

ScGroupDlg::~ScGroupDlg()
{
}

bool ScGroupDlg::GetColsChecked() const
{
    return m_xBtnCols->get_active();
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_24.2.2.orig.tar.xz: libreoffice-24.2.2.2/sc/source/ui/miscdlgs/groupdlg.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#undef SC_DLLIMPLEMENTATION

#include <groupdlg.hxx>

ScGroupDlg::ScGroupDlg(weld::Window* pParent, bool bUngroup, bool bRows)
    : GenericDialogController(pParent,
        bUngroup ?
            OUString("modules/scalc/ui/ungroupdialog.ui") :
            OUString("modules/scalc/ui/groupdialog.ui")
    ,
        bUngroup ?
            OUString("UngroupDialog") :
            OUString("GroupDialog"))
    , m_xBtnRows(m_xBuilder->weld_radio_button("rows"))
    , m_xBtnCols(m_xBuilder->weld_radio_button("cols"))
{
    if (bRows)
        m_xBtnRows->set_active(true);
    else
        m_xBtnCols->set_active(true);
    m_xBtnRows->grab_focus();
}

ScGroupDlg::~ScGroupDlg()
{
}

bool ScGroupDlg::GetColsChecked() const
{
    return m_xBtnCols->get_active();
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
